@@ -12,9 +12,11 @@
 //#include <boost/unordered_map.hpp>
 //#endif
 
+#ifndef NOUSE_EIGEN_LOTUS
 #define   EIGEN_MPL2_ONLY
 #include "Eigen/Dense"
 #include "Eigen/Eigenvalues"
+#endif
 
 namespace Lotus_core {
 
@@ -516,9 +518,19 @@ int call_dsygv(M_tmpl &A, M_tmpl &S, M_tmpl &X,std::vector<double> &ret_lamda);
 
 
 //   solve invese matrix
+
+bool is_Eigen_library(){
+  #ifndef NOUSE_EIGEN_LOTUS
+    return true;
+  #else
+    return false;
+  #endif
+}
+
 template <typename M_tmpl>
 void mat_inverse(M_tmpl &m){
 
+  #ifndef NOUSE_EIGEN_LOTUS
   M_tmpl *m_ptr = &m;
   int I=m_ptr->get_I();
   int J=m_ptr->get_J();
@@ -537,6 +549,10 @@ void mat_inverse(M_tmpl &m){
       m_ptr->set_value(i,j,eM_inv(i,j));
     }
   }
+  #else
+  std::cout<<" can not use Eigen due to compiler option of \"-DNOUSE_EIGEN_LOTUS\" "<<std::endl;
+  exit(1);
+  #endif
 
 }
 
@@ -545,6 +561,7 @@ void mat_inverse(M_tmpl &m){
 template <typename M_tmpl>
 void mat_z_inverse(M_tmpl &m){
 
+  #ifndef NOUSE_EIGEN_LOTUS
   M_tmpl *m_ptr = &m;
   int I=m_ptr->get_I();
   int J=m_ptr->get_J();
@@ -563,7 +580,10 @@ void mat_z_inverse(M_tmpl &m){
       m_ptr->set_value(i,j,eM_inv(i,j));
     }
   }
-
+  #else
+  std::cout<<" can not use Eigen due to compiler option of \"-DNOUSE_EIGEN_LOTUS\" "<<std::endl;
+  exit(1);
+  #endif
 }
 
 
@@ -572,7 +592,7 @@ void mat_z_inverse(M_tmpl &m){
 template <typename M_tmpl>
 void cal_simultaneous_eq(const M_tmpl &A, M_tmpl &X, const M_tmpl &B)
 {
-
+  #ifndef NOUSE_EIGEN_LOTUS
   M_tmpl *A_ptr = const_cast<M_tmpl*>(&A);
   M_tmpl *X_ptr = &X;
   M_tmpl *B_ptr = const_cast<M_tmpl*>(&B);
@@ -604,6 +624,10 @@ void cal_simultaneous_eq(const M_tmpl &A, M_tmpl &X, const M_tmpl &B)
       X_ptr->set_value(i,j,eX(i,j));
     }
   }
+  #else
+  std::cout<<" can not use Eigen due to compiler option of \"-DNOUSE_EIGEN_LOTUS\" "<<std::endl;
+  exit(1);
+  #endif
 
 }
 
@@ -611,6 +635,7 @@ void cal_simultaneous_eq(const M_tmpl &A, M_tmpl &X, const M_tmpl &B)
 template <typename M_tmpl>
 void cal_eigen(const M_tmpl &A, M_tmpl &X, std::vector<double> &ret_lamda){
 
+  #ifndef NOUSE_EIGEN_LOTUS
   using namespace std;
   M_tmpl *A_ptr = const_cast<M_tmpl*>(&A);
   M_tmpl *X_ptr = &X;
@@ -653,6 +678,10 @@ void cal_eigen(const M_tmpl &A, M_tmpl &X, std::vector<double> &ret_lamda){
     }
     index_j++;
   }
+  #else
+  std::cout<<" can not use Eigen due to compiler option of \"-DNOUSE_EIGEN_LOTUS\" "<<std::endl;
+  exit(1);
+  #endif
 
 }
 
@@ -662,6 +691,7 @@ template <typename M_tmpl>
 void cal_eigen(const M_tmpl &A, const M_tmpl &S, M_tmpl &X, std::vector<double> &ret_lamda)
 {
 
+  #ifndef NOUSE_EIGEN_LOTUS
   using namespace std;
   M_tmpl *A_ptr = const_cast<M_tmpl*>(&A);
   M_tmpl *S_ptr = const_cast<M_tmpl*>(&S);
@@ -707,6 +737,10 @@ void cal_eigen(const M_tmpl &A, const M_tmpl &S, M_tmpl &X, std::vector<double>
     }
     index_j++;
   }
+  #else
+  std::cout<<" can not use Eigen due to compiler option of \"-DNOUSE_EIGEN_LOTUS\" "<<std::endl;
+  exit(1);
+  #endif
 
 }
 
@@ -715,6 +749,7 @@ void cal_eigen(const M_tmpl &A, const M_tmpl &S, M_tmpl &X, std::vector<double>
 template <typename M_tmpl>
 void cal_z_eigen(const M_tmpl &A, M_tmpl &X, std::vector<double> &ret_lamda){
 
+  #ifndef NOUSE_EIGEN_LOTUS
   using namespace std;
   M_tmpl *A_ptr = const_cast<M_tmpl*>(&A);
   M_tmpl *X_ptr = &X;
@@ -760,6 +795,10 @@ void cal_z_eigen(const M_tmpl &A, M_tmpl &X, std::vector<double> &ret_lamda){
     index_j++;
   }
 
+  #else
+  std::cout<<" can not use Eigen due to compiler option of \"-DNOUSE_EIGEN_LOTUS\" "<<std::endl;
+  exit(1);
+  #endif
   
 }
 
