@@ -91,10 +91,11 @@ class td_lotus(unittest.TestCase):
 if __name__ == "__main__":
   try:
     from mpi4py import MPI
+    lotus_core_hpp.Util_MPI.set_MPI_COMM_LOTUS()
   except:
+    lotus_core_hpp.Util_MPI.set_MPI_COMM_LOTUS()
     process_num = lotus_core_hpp.Util_MPI.get_mpi_rank()
     if process_num==0: print " mpi4py is not installed"
-  lotus_core_hpp.Util_MPI.set_MPI_COMM_LOTUS()
 
-  unittest.main()
+  unittest.main(exit=False)
 
